﻿/*
' Copyright (c) 2013  DotNetNuclear LLC
'  All rights reserved.
' 
' THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
' TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
' THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
' CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
' DEALINGS IN THE SOFTWARE.
' 
*/

using System;
using DotNetNuke.Entities.Modules;
using DotNetNuke.Services.Exceptions;

namespace DotNetNuclear.Modules.ViewsTutorial
{
    public class ViewsTutorialModuleBase : PortalModuleBase
    {
        public int ItemId
        {
            get
            {
                var qs = Request.QueryString["tid"];
                if (qs != null)
                    return Convert.ToInt32(qs);
                return -1;
            }
        }

        protected void GetModule()
        {
            try
            {
                //Get the control key passed in by the query string
                //if no key is present load the default view control
                string controlKey;
                if (Request.Params["cid"] == null) 
                    controlKey = "ItemList";
                else
                    controlKey = Request.Params["cid"];

                //Get the module path and load the control
                string mPath = getModulePath(ModuleId, TabId, controlKey);
                var objModule = (PortalModuleBase)this.LoadControl(mPath);

                objModule.ModuleConfiguration = this.ModuleConfiguration;
                
                //When you load a control in a control you lose the path to the the resource 
                //file so need to tell the module which resouce file to use.
                objModule.LocalResourceFile = this.LocalResourceFile.Replace("Dispatch", controlKey);
                this.Controls.Add(objModule);
            }
            catch(Exception ex)
            {
                Exceptions.ProcessModuleLoadException(this, ex);
            }
        }

        private string getModulePath(int moduleid, int tabid, string controlKey)
        {
            string path = String.Empty;
            try
            {
                //step 1. get the moduledefid based on the moduleid and tabid
                ModuleController mc = new ModuleController();
                ModuleControlController mcc = new ModuleControlController();
                
                ModuleInfo mi = mc.GetModule(moduleid, tabid);
                if (mi != null)
                {
                    //step 2. using the moduledefid get the module control records
                    var mControl = ModuleControlController.GetModuleControlByControlKey(controlKey, mi.ModuleDefID);
                    if (mControl != null)
                        path = "~/" + mControl.ControlSrc;
                }
            }
            catch(Exception ex)
            {
                Exceptions.ProcessModuleLoadException(this, ex);
            }
            return path;
        }
    }
}